import consola from "consola";
import "reflect-metadata";
import { createExpressServer } from "routing-controllers";
import authchecker from "./authchecker";
import { config, e as errors } from './config';
import loaders from "./loaders/index";
import { ErrorHandler } from './middlewares/ErrorHandler';

const app = createExpressServer({
  authorizationChecker: authchecker,
  middlewares: [ErrorHandler],
  development: config.development,
  cors: true,
  routePrefix: "/api",
  controllers: [__dirname + "/controllers/*.ts"],
});

async function main() {
  await loaders(app);
  app.listen(config.internal_port, () => {
    consola.success(
      `⚡️[server]: Server is running at http://localhost:${config.internal_port}`
    );
  });
}
if (errors === 0) {
  main();
} else {
  consola.error("error");
  // something's wrong
}
